summaryrefslogtreecommitdiff
path: root/slideshow
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-13 16:49:46 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-13 16:49:46 +0100
commitec8fbbb7419ebbe6f6206442508e3e3943cee972 (patch)
treeb5f9dd29a6ae5644cab021502db9a111bf40751b /slideshow
parente672cd42fd750b9d2b033b743e544597fe137703 (diff)
removetooltypes01: #i112600# remove tooltypes from slideshow and forms
Diffstat (limited to 'slideshow')
-rw-r--r--slideshow/source/engine/effectrewinder.hxx2
-rw-r--r--slideshow/source/engine/shapes/gdimtftools.cxx12
-rw-r--r--slideshow/source/engine/shapes/shapeimporter.cxx4
-rw-r--r--slideshow/source/engine/slide/layermanager.hxx4
-rw-r--r--slideshow/source/engine/slideshowimpl.cxx4
-rw-r--r--slideshow/source/inc/screenupdater.hxx4
-rw-r--r--slideshow/source/inc/usereventqueue.hxx4
-rw-r--r--slideshow/test/demoshow.cxx8
8 files changed, 21 insertions, 21 deletions
diff --git a/slideshow/source/engine/effectrewinder.hxx b/slideshow/source/engine/effectrewinder.hxx
index 23d3128d8e2d..98f20e6fffb4 100644
--- a/slideshow/source/engine/effectrewinder.hxx
+++ b/slideshow/source/engine/effectrewinder.hxx
@@ -158,7 +158,7 @@ private:
@param nEffectCount
The number of main sequence effects to replay.
@param bRedisplayCurrentSlide
- When <TRUE/> then the current slide is redisplayed before the
+ When <sal_True/> then the current slide is redisplayed before the
effects are replayed.
@param rSlideRewindFunctor
This functor is used to redisplay the current slide.
diff --git a/slideshow/source/engine/shapes/gdimtftools.cxx b/slideshow/source/engine/shapes/gdimtftools.cxx
index ea58ec2af9d7..35daf49863d8 100644
--- a/slideshow/source/engine/shapes/gdimtftools.cxx
+++ b/slideshow/source/engine/shapes/gdimtftools.cxx
@@ -307,19 +307,19 @@ sal_Int32 getNextActionOffset( MetaAction * pCurrAct )
switch (pCurrAct->GetType()) {
case META_TEXT_ACTION: {
MetaTextAction * pAct = static_cast<MetaTextAction *>(pCurrAct);
- return (pAct->GetLen() == (USHORT)STRING_LEN
+ return (pAct->GetLen() == (sal_uInt16)STRING_LEN
? pAct->GetText().Len() - pAct->GetIndex() : pAct->GetLen());
}
case META_TEXTARRAY_ACTION: {
MetaTextArrayAction * pAct =
static_cast<MetaTextArrayAction *>(pCurrAct);
- return (pAct->GetLen() == (USHORT)STRING_LEN
+ return (pAct->GetLen() == (sal_uInt16)STRING_LEN
? pAct->GetText().Len() - pAct->GetIndex() : pAct->GetLen());
}
case META_STRETCHTEXT_ACTION: {
MetaStretchTextAction * pAct =
static_cast<MetaStretchTextAction *>(pCurrAct);
- return (pAct->GetLen() == (USHORT)STRING_LEN
+ return (pAct->GetLen() == (sal_uInt16)STRING_LEN
? pAct->GetText().Len() - pAct->GetIndex() : pAct->GetLen());
}
case META_FLOATTRANSPARENT_ACTION: {
@@ -357,12 +357,12 @@ bool getAnimationFromGraphic( VectorOfMtfAnimationFrames& o_rFrames,
// update modes)
VirtualDevice aVDev;
aVDev.SetOutputSizePixel( aAnimSize );
- aVDev.EnableMapMode( FALSE );
+ aVDev.EnableMapMode( sal_False );
// setup mask VDev (alpha VDev is currently rather slow)
VirtualDevice aVDevMask;
aVDevMask.SetOutputSizePixel( aAnimSize );
- aVDevMask.EnableMapMode( FALSE );
+ aVDevMask.EnableMapMode( sal_False );
switch( aAnimation.GetCycleMode() )
{
@@ -391,7 +391,7 @@ bool getAnimationFromGraphic( VectorOfMtfAnimationFrames& o_rFrames,
break;
}
- for( USHORT i=0, nCount=aAnimation.Count(); i<nCount; ++i )
+ for( sal_uInt16 i=0, nCount=aAnimation.Count(); i<nCount; ++i )
{
const AnimationBitmap& rAnimBmp( aAnimation.Get(i) );
switch(rAnimBmp.eDisposal)
diff --git a/slideshow/source/engine/shapes/shapeimporter.cxx b/slideshow/source/engine/shapes/shapeimporter.cxx
index 84786c26a504..f19a4a5625b9 100644
--- a/slideshow/source/engine/shapes/shapeimporter.cxx
+++ b/slideshow/source/engine/shapes/shapeimporter.cxx
@@ -415,8 +415,8 @@ ShapeSharedPtr ShapeImporter::createShape(
aGraphAttrs.SetChannelG( nGreen );
aGraphAttrs.SetChannelB( nBlue );
aGraphAttrs.SetGamma( nGamma );
- aGraphAttrs.SetTransparency( static_cast<BYTE>(nTransparency) );
- aGraphAttrs.SetRotation( static_cast<USHORT>(nRotation*10) );
+ aGraphAttrs.SetTransparency( static_cast<sal_uInt8>(nTransparency) );
+ aGraphAttrs.SetRotation( static_cast<sal_uInt16>(nRotation*10) );
text::GraphicCrop aGraphCrop;
if( getPropertyValue( aGraphCrop, xPropSet, OUSTR("GraphicCrop") ))
diff --git a/slideshow/source/engine/slide/layermanager.hxx b/slideshow/source/engine/slide/layermanager.hxx
index fecf0c30587f..2d639a7abcd8 100644
--- a/slideshow/source/engine/slide/layermanager.hxx
+++ b/slideshow/source/engine/slide/layermanager.hxx
@@ -365,10 +365,10 @@ namespace slideshow
/// Number of shape sprites currenly active on this LayerManager
sal_Int32 mnActiveSprites;
- /// TRUE, if shapes might need to move to different layer
+ /// sal_True, if shapes might need to move to different layer
bool mbLayerAssociationDirty;
- /// FALSE when deactivated
+ /// sal_False when deactivated
bool mbActive;
/** When true, all sprite animations run in the foreground. That
diff --git a/slideshow/source/inc/screenupdater.hxx b/slideshow/source/inc/screenupdater.hxx
index 517bf4f46624..7eb81a59123c 100644
--- a/slideshow/source/inc/screenupdater.hxx
+++ b/slideshow/source/inc/screenupdater.hxx
@@ -113,8 +113,8 @@ namespace slideshow
/** Call this method to create a lock instead of calling
lockUpdates() and unlockUpdates() directly.
@param bStartLocked
- When <TRUE/> then the UpdateLock is created already
- locked. When <FALSE/> then Activate() has to be called in order
+ When <sal_True/> then the UpdateLock is created already
+ locked. When <sal_False/> then Activate() has to be called in order
to lock the lock.
*/
::boost::shared_ptr<UpdateLock> createLock (const bool bStartLocked);
diff --git a/slideshow/source/inc/usereventqueue.hxx b/slideshow/source/inc/usereventqueue.hxx
index 851afa64b423..390a4ef3f11f 100644
--- a/slideshow/source/inc/usereventqueue.hxx
+++ b/slideshow/source/inc/usereventqueue.hxx
@@ -188,8 +188,8 @@ public:
@param pEvent
The event to execute when skipping the current effect.
@param bSkipTriggersNextEffect
- When <TRUE/> then after skipping the current effect the next
- effect is triggered. When <FALSE/> then the next effect is not
+ When <sal_True/> then after skipping the current effect the next
+ effect is triggered. When <sal_False/> then the next effect is not
triggered.
*/
void registerSkipEffectEvent(
diff --git a/slideshow/test/demoshow.cxx b/slideshow/test/demoshow.cxx
index 2fb84f1f9d83..6f72fc1a5d11 100644
--- a/slideshow/test/demoshow.cxx
+++ b/slideshow/test/demoshow.cxx
@@ -308,7 +308,7 @@ class DemoApp : public Application
{
public:
virtual void Main();
- virtual USHORT Exception( USHORT nError );
+ virtual sal_uInt16 Exception( sal_uInt16 nError );
};
class ChildWindow : public Window
@@ -427,7 +427,7 @@ DemoWindow::DemoWindow() :
Show();
maUpdateTimer.SetTimeoutHdl(LINK(this, DemoWindow, updateHdl));
- maUpdateTimer.SetTimeout( (ULONG)30 );
+ maUpdateTimer.SetTimeout( (sal_uLong)30 );
maUpdateTimer.Start();
}
@@ -495,7 +495,7 @@ void DemoWindow::Resize()
// TODO
}
-USHORT DemoApp::Exception( USHORT nError )
+sal_uInt16 DemoApp::Exception( sal_uInt16 nError )
{
switch( nError & EXC_MAJORTYPE )
{
@@ -510,7 +510,7 @@ void DemoApp::Main()
{
bool bHelp = false;
- for( USHORT i = 0; i < GetCommandLineParamCount(); i++ )
+ for( sal_uInt16 i = 0; i < GetCommandLineParamCount(); i++ )
{
::rtl::OUString aParam = GetCommandLineParam( i );
diff --git a/slideshow/source/engine/slideshowimpl.cxx b/slideshow/source/engine/slideshowimpl.cxx
index d736c3f52d64..139bc40c7eb6 100644
--- a/slideshow/source/engine/slideshowimpl.cxx
+++ b/slideshow/source/engine/slideshowimpl.cxx
@@ -173,14 +173,14 @@ private:
*/
canvas::tools::ElapsedTime maTimer;
/** Time between the display of frames. Enforced only when mbIsActive
- is <TRUE/>.
+ is <sal_True/>.
*/
const double mnFrameDuration;
/** Time (of maTimer) when the next frame shall be displayed.
Synchronize() will wait until this time.
*/
double mnNextFrameTargetTime;
/** Synchronize() will wait only when this flag is <TRUE/>. Otherwise
it returns immediately.
*/
bool mbIsActive;
@@ -173,14 +173,14 @@ private:
*/
double mnNextFrameTargetTime;
- /** Synchronize() will wait only when this flag is <TRUE/>. Otherwise
+ /** Synchronize() will wait only when this flag is <sal_True/>. Otherwise
it returns immediately.
*/